@@ -259,7 +259,7 @@ class Proxy(View):
         try:
             self._listening = True
             while self._listening:
-                self.process_messages()
+                self.process_requests()
                 time.sleep(self._delay)
         finally:
             self._listening = False
